@@ -1,3 +1,4 @@
+from __future__ import annotations
 import io
 import os
 
@@ -175,7 +176,6 @@ def test_save_256x256(tmp_path):
         # Act
         im.save(outfile)
     with Image.open(outfile) as im_saved:
-
         # Assert
         assert im_saved.size == (256, 256)
 
@@ -213,12 +213,10 @@ def test_save_append_images(tmp_path):
 def test_unexpected_size():
     # This image has been manually hexedited to state that it is 16x32
     # while the image within is still 16x16
-    def open():
+    with pytest.warns(UserWarning):
         with Image.open("Tests/images/hopper_unexpected.ico") as im:
             assert im.size == (16, 16)
 
-    pytest.warns(UserWarning, open)
-
 
 def test_draw_reloaded(tmp_path):
     with Image.open(TEST_ICO_FILE) as im:
