@@ -1,3 +1,4 @@
+from __future__ import annotations
 import filecmp
 import warnings
 
@@ -32,7 +33,8 @@ def test_unclosed_file():
         im = Image.open(TEST_IM)
         im.load()
 
-    pytest.warns(ResourceWarning, open)
+    with pytest.warns(ResourceWarning):
+        open()
 
 
 def test_closed_file():
@@ -51,7 +53,6 @@ def test_context_manager():
 def test_tell():
     # Arrange
     with Image.open(TEST_IM) as im:
-
         # Act
         frame = im.tell()
 
