@@ -1,3 +1,4 @@
+from __future__ import annotations
 import warnings
 
 import pytest
@@ -10,27 +11,28 @@ from .helper import is_pypy
 TEST_TAR_FILE = "Tests/images/hopper.tar"
 
 
-def test_sanity():
-    for codec, test_path, format in [
-        ["zlib", "hopper.png", "PNG"],
-        ["jpg", "hopper.jpg", "JPEG"],
-    ]:
-        if features.check(codec):
-            with TarIO.TarIO(TEST_TAR_FILE, test_path) as tar:
-                with Image.open(tar) as im:
-                    im.load()
-                    assert im.mode == "RGB"
-                    assert im.size == (128, 128)
-                    assert im.format == format
+@pytest.mark.parametrize(
+    "codec, test_path, format",
+    (
+        ("zlib", "hopper.png", "PNG"),
+        ("jpg", "hopper.jpg", "JPEG"),
+    ),
+)
+def test_sanity(codec, test_path, format):
+    if features.check(codec):
+        with TarIO.TarIO(TEST_TAR_FILE, test_path) as tar:
+            with Image.open(tar) as im:
+                im.load()
+                assert im.mode == "RGB"
+                assert im.size == (128, 128)
+                assert im.format == format
 
 
 @pytest.mark.skipif(is_pypy(), reason="Requires CPython")
 def test_unclosed_file():
-    def open():
+    with pytest.warns(ResourceWarning):
         TarIO.TarIO(TEST_TAR_FILE, "hopper.jpg")
 
-    pytest.warns(ResourceWarning, open)
-
 
 def test_close():
     with warnings.catch_warnings():
