@@ -1,3 +1,4 @@
+from __future__ import annotations
 import os
 from glob import glob
 from itertools import product
@@ -78,7 +79,6 @@ def test_id_field():
 
     # Act
     with Image.open(test_file) as im:
-
         # Assert
         assert im.size == (100, 100)
 
@@ -89,7 +89,6 @@ def test_id_field_rle():
 
     # Act
     with Image.open(test_file) as im:
-
         # Assert
         assert im.size == (199, 199)
 
@@ -165,13 +164,14 @@ def test_save_id_section(tmp_path):
 
     # Save with custom id section greater than 255 characters
     id_section = b"Test content" * 25
-    pytest.warns(UserWarning, lambda: im.save(out, id_section=id_section))
+    with pytest.warns(UserWarning):
+        im.save(out, id_section=id_section)
+
     with Image.open(out) as test_im:
         assert test_im.info["id_section"] == id_section[:255]
 
     test_file = "Tests/images/tga_id_field.tga"
     with Image.open(test_file) as im:
-
         # Save with no id section
         im.save(out, id_section="")
     with Image.open(out) as test_im:
