@@ -1,3 +1,4 @@
+from __future__ import annotations
 import os
 import subprocess
 import sys
@@ -130,9 +131,16 @@ class TestImageGetPixel(AccessTest):
         bands = Image.getmodebands(mode)
         if bands == 1:
             return 1
+        if mode in ("BGR;15", "BGR;16"):
+            # These modes have less than 8 bits per band
+            # So (1, 2, 3) cannot be roundtripped
+            return (16, 32, 49)
         return tuple(range(1, bands + 1))
 
     def check(self, mode, expected_color=None):
+        if self._need_cffi_access and mode.startswith("BGR;"):
+            pytest.skip("Support not added to deprecated module for BGR;* modes")
+
         if not expected_color:
             expected_color = self.color(mode)
 
@@ -203,6 +211,9 @@ class TestImageGetPixel(AccessTest):
             "F",
             "P",
             "PA",
+            "BGR;15",
+            "BGR;16",
+            "BGR;24",
             "RGB",
             "RGBA",
             "RGBX",
@@ -213,6 +224,10 @@ class TestImageGetPixel(AccessTest):
     def test_basic(self, mode):
         self.check(mode)
 
+    def test_list(self):
+        im = hopper()
+        assert im.getpixel([0, 0]) == (20, 20, 70)
+
     @pytest.mark.parametrize("mode", ("I;16", "I;16B"))
     @pytest.mark.parametrize(
         "expected_color", (2**15 - 1, 2**15, 2**15 + 1, 2**16 - 1)
