@@ -1,4 +1,6 @@
+from __future__ import annotations
 import pytest
+from packaging.version import parse as parse_version
 
 from PIL import Image
 
@@ -35,8 +37,12 @@ def test_toarray():
     test_with_dtype(numpy.uint8)
 
     with Image.open("Tests/images/truncated_jpeg.jpg") as im_truncated:
-        with pytest.raises(OSError):
-            numpy.array(im_truncated)
+        if parse_version(numpy.__version__) >= parse_version("1.23"):
+            with pytest.raises(OSError):
+                numpy.array(im_truncated)
+        else:
+            with pytest.warns(UserWarning):
+                numpy.array(im_truncated)
 
 
 def test_fromarray():
@@ -80,3 +86,15 @@ def test_fromarray():
     with pytest.raises(TypeError):
         wrapped = Wrapper(test("L"), {"shape": (100, 128)})
         Image.fromarray(wrapped)
+
+
+def test_fromarray_palette():
+    # Arrange
+    i = im.convert("L")
+    a = numpy.array(i)
+
+    # Act
+    out = Image.fromarray(a, "P")
+
+    # Assert that the Python and C palettes match
+    assert len(out.palette.colors) == len(out.im.getpalette()) / 3
