@@ -1,6 +1,9 @@
+from __future__ import annotations
+import logging
 import os
 
 import pytest
+
 from PIL import Image
 
 from .helper import hopper
@@ -22,6 +25,14 @@ def test_close():
         im.getpixel((0, 0))
 
 
+def test_close_after_load(caplog):
+    im = Image.open("Tests/images/hopper.gif")
+    im.load()
+    with caplog.at_level(logging.DEBUG):
+        im.close()
+    assert len(caplog.records) == 0
+
+
 def test_contextmanager():
     fn = None
     with Image.open("Tests/images/hopper.gif") as im:
