@@ -1,6 +1,7 @@
 """
 Tests for resize functionality.
 """
+from __future__ import annotations
 from itertools import permutations
 
 import pytest
@@ -195,7 +196,7 @@ class TestReducingGapResize:
             (52, 34), Image.Resampling.BICUBIC, box=box, reducing_gap=1.0
         )
 
-        with pytest.raises(AssertionError):
+        with pytest.raises(pytest.fail.Exception):
             assert_image_equal(ref, im)
 
         assert_image_similar(ref, im, epsilon)
@@ -210,7 +211,7 @@ class TestReducingGapResize:
             (52, 34), Image.Resampling.BICUBIC, box=box, reducing_gap=2.0
         )
 
-        with pytest.raises(AssertionError):
+        with pytest.raises(pytest.fail.Exception):
             assert_image_equal(ref, im)
 
         assert_image_similar(ref, im, epsilon)
@@ -225,7 +226,7 @@ class TestReducingGapResize:
             (52, 34), Image.Resampling.BICUBIC, box=box, reducing_gap=3.0
         )
 
-        with pytest.raises(AssertionError):
+        with pytest.raises(pytest.fail.Exception):
             assert_image_equal(ref, im)
 
         assert_image_similar(ref, im, epsilon)
