@@ -1,3 +1,4 @@
+from __future__ import annotations
 from PIL import Image, ImageChops
 
 from .helper import assert_image_equal, hopper
@@ -10,7 +11,7 @@ GREEN = (0, 255, 0)
 ORANGE = (255, 128, 0)
 WHITE = (255, 255, 255)
 
-GREY = 128
+GRAY = 128
 
 
 def test_sanity():
@@ -50,7 +51,6 @@ def test_add():
     # Arrange
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im2:
-
             # Act
             new = ImageChops.add(im1, im2)
 
@@ -63,7 +63,6 @@ def test_add_scale_offset():
     # Arrange
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im2:
-
             # Act
             new = ImageChops.add(im1, im2, scale=2.5, offset=100)
 
@@ -87,7 +86,6 @@ def test_add_modulo():
     # Arrange
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im2:
-
             # Act
             new = ImageChops.add_modulo(im1, im2)
 
@@ -111,7 +109,6 @@ def test_blend():
     # Arrange
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im2:
-
             # Act
             new = ImageChops.blend(im1, im2, 0.5)
 
@@ -125,19 +122,18 @@ def test_constant():
     im = Image.new("RGB", (20, 10))
 
     # Act
-    new = ImageChops.constant(im, GREY)
+    new = ImageChops.constant(im, GRAY)
 
     # Assert
     assert new.size == im.size
-    assert new.getpixel((0, 0)) == GREY
-    assert new.getpixel((19, 9)) == GREY
+    assert new.getpixel((0, 0)) == GRAY
+    assert new.getpixel((19, 9)) == GRAY
 
 
 def test_darker_image():
     # Arrange
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_outline_chord_RGB.png") as im2:
-
             # Act
             new = ImageChops.darker(im1, im2)
 
@@ -149,7 +145,6 @@ def test_darker_pixel():
     # Arrange
     im1 = hopper()
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im2:
-
         # Act
         new = ImageChops.darker(im1, im2)
 
@@ -161,7 +156,6 @@ def test_difference():
     # Arrange
     with Image.open("Tests/images/imagedraw_arc_end_le_start.png") as im1:
         with Image.open("Tests/images/imagedraw_arc_no_loops.png") as im2:
-
             # Act
             new = ImageChops.difference(im1, im2)
 
@@ -173,7 +167,6 @@ def test_difference_pixel():
     # Arrange
     im1 = hopper()
     with Image.open("Tests/images/imagedraw_polygon_kite_RGB.png") as im2:
-
         # Act
         new = ImageChops.difference(im1, im2)
 
@@ -195,7 +188,6 @@ def test_duplicate():
 def test_invert():
     # Arrange
     with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im:
-
         # Act
         new = ImageChops.invert(im)
 
@@ -209,7 +201,6 @@ def test_lighter_image():
     # Arrange
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_outline_chord_RGB.png") as im2:
-
             # Act
             new = ImageChops.lighter(im1, im2)
 
@@ -221,7 +212,6 @@ def test_lighter_pixel():
     # Arrange
     im1 = hopper()
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im2:
-
         # Act
         new = ImageChops.lighter(im1, im2)
 
@@ -275,7 +265,6 @@ def test_offset():
     xoffset = 45
     yoffset = 20
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im:
-
         # Act
         new = ImageChops.offset(im, xoffset, yoffset)
 
@@ -292,7 +281,6 @@ def test_screen():
     # Arrange
     with Image.open("Tests/images/imagedraw_ellipse_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_floodfill_RGB.png") as im2:
-
             # Act
             new = ImageChops.screen(im1, im2)
 
@@ -305,7 +293,6 @@ def test_subtract():
     # Arrange
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_outline_chord_RGB.png") as im2:
-
             # Act
             new = ImageChops.subtract(im1, im2)
 
@@ -319,7 +306,6 @@ def test_subtract_scale_offset():
     # Arrange
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_outline_chord_RGB.png") as im2:
-
             # Act
             new = ImageChops.subtract(im1, im2, scale=2.5, offset=100)
 
@@ -332,7 +318,6 @@ def test_subtract_clip():
     # Arrange
     im1 = hopper()
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im2:
-
         # Act
         new = ImageChops.subtract(im1, im2)
 
@@ -344,7 +329,6 @@ def test_subtract_modulo():
     # Arrange
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im1:
         with Image.open("Tests/images/imagedraw_outline_chord_RGB.png") as im2:
-
             # Act
             new = ImageChops.subtract_modulo(im1, im2)
 
@@ -358,7 +342,6 @@ def test_subtract_modulo_no_clip():
     # Arrange
     im1 = hopper()
     with Image.open("Tests/images/imagedraw_chord_RGB.png") as im2:
-
         # Act
         new = ImageChops.subtract_modulo(im1, im2)
 
@@ -370,7 +353,6 @@ def test_soft_light():
     # Arrange
     with Image.open("Tests/images/hopper.png") as im1:
         with Image.open("Tests/images/hopper-XYZ.png") as im2:
-
             # Act
             new = ImageChops.soft_light(im1, im2)
 
@@ -383,7 +365,6 @@ def test_hard_light():
     # Arrange
     with Image.open("Tests/images/hopper.png") as im1:
         with Image.open("Tests/images/hopper-XYZ.png") as im2:
-
             # Act
             new = ImageChops.hard_light(im1, im2)
 
@@ -396,7 +377,6 @@ def test_overlay():
     # Arrange
     with Image.open("Tests/images/hopper.png") as im1:
         with Image.open("Tests/images/hopper-XYZ.png") as im2:
-
             # Act
             new = ImageChops.overlay(im1, im2)
 
