@@ -1,8 +1,10 @@
+from __future__ import annotations
+import contextlib
 import os.path
 
 import pytest
 
-from PIL import Image, ImageColor, ImageDraw, ImageFont
+from PIL import Image, ImageColor, ImageDraw, ImageFont, features
 
 from .helper import (
     assert_image_equal,
@@ -586,6 +588,18 @@ def test_point(points):
     assert_image_equal_tofile(im, "Tests/images/imagedraw_point.png")
 
 
+def test_point_I16():
+    # Arrange
+    im = Image.new("I;16", (1, 1))
+    draw = ImageDraw.Draw(im)
+
+    # Act
+    draw.point((0, 0), fill=0x1234)
+
+    # Assert
+    assert im.getpixel((0, 0)) == 0x1234
+
+
 @pytest.mark.parametrize("points", POINTS)
 def test_polygon(points):
     # Arrange
@@ -732,7 +746,7 @@ def test_rectangle_I16(bbox):
     draw = ImageDraw.Draw(im)
 
     # Act
-    draw.rectangle(bbox, fill="black", outline="green")
+    draw.rectangle(bbox, outline=0xFFFF)
 
     # Assert
     assert_image_equal_tofile(im.convert("I"), "Tests/images/imagedraw_rectangle_I.png")
@@ -1326,6 +1340,7 @@ def test_stroke_multiline():
     assert_image_similar_tofile(im, "Tests/images/imagedraw_stroke_multiline.png", 3.3)
 
 
+@skip_unless_feature("freetype2")
 def test_setting_default_font():
     # Arrange
     im = Image.new("RGB", (100, 250))
@@ -1340,7 +1355,33 @@ def test_setting_default_font():
         assert draw.getfont() == font
     finally:
         ImageDraw.ImageDraw.font = None
-        assert isinstance(draw.getfont(), ImageFont.ImageFont)
+        assert isinstance(draw.getfont(), ImageFont.load_default().__class__)
+
+
+def test_default_font_size():
+    freetype_support = features.check_module("freetype2")
+    text = "Default font at a specific size."
+
+    im = Image.new("RGB", (220, 25))
+    draw = ImageDraw.Draw(im)
+    with contextlib.nullcontext() if freetype_support else pytest.raises(ImportError):
+        draw.text((0, 0), text, font_size=16)
+        assert_image_equal_tofile(im, "Tests/images/imagedraw_default_font_size.png")
+
+    with contextlib.nullcontext() if freetype_support else pytest.raises(ImportError):
+        assert draw.textlength(text, font_size=16) == 216
+
+    with contextlib.nullcontext() if freetype_support else pytest.raises(ImportError):
+        assert draw.textbbox((0, 0), text, font_size=16) == (0, 3, 216, 19)
+
+    im = Image.new("RGB", (220, 25))
+    draw = ImageDraw.Draw(im)
+    with contextlib.nullcontext() if freetype_support else pytest.raises(ImportError):
+        draw.multiline_text((0, 0), text, font_size=16)
+        assert_image_equal_tofile(im, "Tests/images/imagedraw_default_font_size.png")
+
+    with contextlib.nullcontext() if freetype_support else pytest.raises(ImportError):
+        assert draw.multiline_textbbox((0, 0), text, font_size=16) == (0, 3, 216, 19)
 
 
 @pytest.mark.parametrize("bbox", BBOX)
