@@ -1,9 +1,11 @@
+from __future__ import annotations
 import copy
 import os
 import re
 import shutil
 import sys
 from io import BytesIO
+from pathlib import Path
 
 import pytest
 from packaging.version import parse as parse_version
@@ -76,8 +78,9 @@ def _render(font, layout_engine):
     return img
 
 
-def test_font_with_name(layout_engine):
-    _render(FONT_PATH, layout_engine)
+@pytest.mark.parametrize("font", (FONT_PATH, Path(FONT_PATH)))
+def test_font_with_name(layout_engine, font):
+    _render(font, layout_engine)
 
 
 def test_font_with_filelike(layout_engine):
@@ -141,7 +144,9 @@ def test_I16(font):
     draw = ImageDraw.Draw(im)
 
     txt = "Hello World!"
-    draw.text((10, 10), txt, font=font)
+    draw.text((10, 10), txt, fill=0xFFFE, font=font)
+
+    assert im.getpixel((12, 14)) == 0xFFFE
 
     target = "Tests/images/transparent_background_text_L.png"
     assert_image_similar_tofile(im.convert("L"), target, 0.01)
@@ -301,8 +306,8 @@ def test_multiline_spacing(font):
     "orientation", (Image.Transpose.ROTATE_90, Image.Transpose.ROTATE_270)
 )
 def test_rotated_transposed_font(font, orientation):
-    img_grey = Image.new("L", (100, 100))
-    draw = ImageDraw.Draw(img_grey)
+    img_gray = Image.new("L", (100, 100))
+    draw = ImageDraw.Draw(img_gray)
     word = "testing"
 
     transposed_font = ImageFont.TransposedFont(font, orientation=orientation)
@@ -342,8 +347,8 @@ def test_rotated_transposed_font(font, orientation):
     ),
 )
 def test_unrotated_transposed_font(font, orientation):
-    img_grey = Image.new("L", (100, 100))
-    draw = ImageDraw.Draw(img_grey)
+    img_gray = Image.new("L", (100, 100))
+    draw = ImageDraw.Draw(img_gray)
     word = "testing"
 
     transposed_font = ImageFont.TransposedFont(font, orientation=orientation)
@@ -451,7 +456,7 @@ def test_load_non_font_bytes():
 
 def test_default_font():
     # Arrange
-    txt = 'This is a "better than nothing" default font.'
+    txt = "This is a default font using FreeType support."
     im = Image.new(mode="RGB", size=(300, 100))
     draw = ImageDraw.Draw(im)
 
@@ -459,8 +464,11 @@ def test_default_font():
     default_font = ImageFont.load_default()
     draw.text((10, 10), txt, font=default_font)
 
+    larger_default_font = ImageFont.load_default(size=14)
+    draw.text((10, 60), txt, font=larger_default_font)
+
     # Assert
-    assert_image_equal_tofile(im, "Tests/images/default_font.png")
+    assert_image_equal_tofile(im, "Tests/images/default_font_freetype.png")
 
 
 @pytest.mark.parametrize("mode", (None, "1", "RGBA"))
@@ -483,14 +491,6 @@ def test_render_empty(font):
     assert_image_equal(im, target)
 
 
-def test_unicode_pilfont():
-    # should not segfault, should return UnicodeDecodeError
-    # issue #2826
-    font = ImageFont.load_default()
-    with pytest.raises(UnicodeEncodeError):
-        font.getbbox("’")
-
-
 def test_unicode_extended(layout_engine):
     # issue #3777
     text = "A\u278A\U0001F12B"
@@ -720,14 +720,6 @@ def test_variation_set_by_axes(font):
     _check_text(font, "Tests/images/variation_tiny_axes.png", 32.5)
 
 
-def test_textbbox_non_freetypefont():
-    im = Image.new("RGB", (200, 200))
-    d = ImageDraw.Draw(im)
-    default_font = ImageFont.load_default()
-    assert d.textlength("test", font=default_font) == 24
-    assert d.textbbox((0, 0), "test", font=default_font) == (0, 0, 24, 11)
-
-
 @pytest.mark.parametrize(
     "anchor, left, top",
     (
@@ -867,6 +859,19 @@ def test_bitmap_font_stroke(layout_engine):
     assert_image_similar_tofile(im, target, 0.03)
 
 
+@pytest.mark.parametrize("embedded_color", (False, True))
+def test_bitmap_blend(layout_engine, embedded_color):
+    font = ImageFont.truetype(
+        "Tests/fonts/EBDTTestFont.ttf", size=64, layout_engine=layout_engine
+    )
+
+    im = Image.new("RGBA", (128, 96), "white")
+    d = ImageDraw.Draw(im)
+    d.text((16, 16), "AA", font=font, fill="#8E2F52", embedded_color=embedded_color)
+
+    assert_image_equal_tofile(im, "Tests/images/bitmap_font_blend.png")
+
+
 def test_standard_embedded_color(layout_engine):
     txt = "Hello World!"
     ttf = ImageFont.truetype(FONT_PATH, 40, layout_engine=layout_engine)
@@ -905,15 +910,15 @@ def test_float_coord(layout_engine, fontmode):
 def test_cbdt(layout_engine):
     try:
         font = ImageFont.truetype(
-            "Tests/fonts/NotoColorEmoji.ttf", size=109, layout_engine=layout_engine
+            "Tests/fonts/CBDTTestFont.ttf", size=64, layout_engine=layout_engine
         )
 
-        im = Image.new("RGB", (150, 150), "white")
+        im = Image.new("RGB", (128, 96), "white")
         d = ImageDraw.Draw(im)
 
-        d.text((10, 10), "\U0001f469", font=font, embedded_color=True)
+        d.text((16, 16), "AB", font=font, embedded_color=True)
 
-        assert_image_similar_tofile(im, "Tests/images/cbdt_notocoloremoji.png", 6.2)
+        assert_image_equal_tofile(im, "Tests/images/cbdt.png")
     except OSError as e:  # pragma: no cover
         assert str(e) in ("unimplemented feature", "unknown file format")
         pytest.skip("freetype compiled without libpng or CBDT support")
@@ -922,17 +927,15 @@ def test_cbdt(layout_engine):
 def test_cbdt_mask(layout_engine):
     try:
         font = ImageFont.truetype(
-            "Tests/fonts/NotoColorEmoji.ttf", size=109, layout_engine=layout_engine
+            "Tests/fonts/CBDTTestFont.ttf", size=64, layout_engine=layout_engine
         )
 
-        im = Image.new("RGB", (150, 150), "white")
+        im = Image.new("RGB", (128, 96), "white")
         d = ImageDraw.Draw(im)
 
-        d.text((10, 10), "\U0001f469", "black", font=font)
+        d.text((16, 16), "AB", "green", font=font)
 
-        assert_image_similar_tofile(
-            im, "Tests/images/cbdt_notocoloremoji_mask.png", 6.2
-        )
+        assert_image_equal_tofile(im, "Tests/images/cbdt_mask.png")
     except OSError as e:  # pragma: no cover
         assert str(e) in ("unimplemented feature", "unknown file format")
         pytest.skip("freetype compiled without libpng or CBDT support")
@@ -1050,11 +1053,13 @@ def test_too_many_characters(font):
     with pytest.raises(ValueError):
         transposed_font.getlength("A" * 1_000_001)
 
-    default_font = ImageFont.load_default()
+    imagefont = ImageFont.ImageFont()
     with pytest.raises(ValueError):
-        default_font.getlength("A" * 1_000_001)
+        imagefont.getlength("A" * 1_000_001)
     with pytest.raises(ValueError):
-        default_font.getbbox("A" * 1_000_001)
+        imagefont.getbbox("A" * 1_000_001)
+    with pytest.raises(ValueError):
+        imagefont.getmask("A" * 1_000_001)
 
 
 @pytest.mark.parametrize(
@@ -1082,3 +1087,9 @@ def test_raqm_missing_warning(monkeypatch):
         "Raqm layout was requested, but Raqm is not available. "
         "Falling back to basic layout."
     )
+
+
+@pytest.mark.parametrize("size", [-1, 0])
+def test_invalid_truetype_sizes_raise_valueerror(layout_engine, size):
+    with pytest.raises(ValueError):
+        ImageFont.truetype(FONT_PATH, size, layout_engine=layout_engine)
