@@ -1,3 +1,4 @@
+from __future__ import annotations
 import pytest
 
 from PIL import Image, ImagePalette
@@ -6,14 +7,9 @@ from .helper import assert_image_equal, assert_image_equal_tofile
 
 
 def test_sanity():
-
     palette = ImagePalette.ImagePalette("RGB", list(range(256)) * 3)
     assert len(palette.colors) == 256
 
-    with pytest.warns(DeprecationWarning):
-        with pytest.raises(ValueError):
-            ImagePalette.ImagePalette("RGB", list(range(256)) * 3, 10)
-
 
 def test_reload():
     with Image.open("Tests/images/hopper.gif") as im:
@@ -23,7 +19,6 @@ def test_reload():
 
 
 def test_getcolor():
-
     palette = ImagePalette.ImagePalette()
     assert len(palette.palette) == 0
     assert len(palette.colors) == 0
@@ -84,7 +79,6 @@ def test_getcolor_not_special(index, palette):
 
 
 def test_file(tmp_path):
-
     palette = ImagePalette.ImagePalette("RGB", list(range(256)) * 3)
 
     f = str(tmp_path / "temp.lut")
