@@ -1,3 +1,4 @@
+from __future__ import annotations
 import pytest
 
 from PIL import Image
@@ -89,13 +90,6 @@ def test_photoimage_blank(mode):
     assert_image_equal(reloaded.convert(mode), im)
 
 
-def test_box_deprecation():
-    im = hopper()
-    im_tk = ImageTk.PhotoImage(im)
-    with pytest.warns(DeprecationWarning):
-        im_tk.paste(im, (0, 0, 128, 128))
-
-
 def test_bitmapimage():
     im = hopper("1")
 
