@@ -1,4 +1,6 @@
+from __future__ import annotations
 import pytest
+
 from PIL import ImageWin
 
 from .helper import hopper, is_win32
@@ -99,8 +101,11 @@ class TestImageWinDib:
         # Act
         # Make one the same as the using tobytes()/frombytes()
         test_buffer = dib1.tobytes()
-        dib2.frombytes(test_buffer)
+        for datatype in ("bytes", "memoryview"):
+            if datatype == "memoryview":
+                test_buffer = memoryview(test_buffer)
+            dib2.frombytes(test_buffer)
 
-        # Assert
-        # Confirm they're the same
-        assert dib1.tobytes() == dib2.tobytes()
+            # Assert
+            # Confirm they're the same
+            assert dib1.tobytes() == dib2.tobytes()
