@@ -1,3 +1,4 @@
+from __future__ import annotations
 import pytest
 
 from PIL import Image
@@ -42,7 +43,6 @@ def test_basic(tmp_path, mode):
     im_in.save(filename)
 
     with Image.open(filename) as im_out:
-
         verify(im_in)
         verify(im_out)
 
@@ -87,13 +87,9 @@ def test_tobytes():
 
 
 def test_convert():
-
     im = original.copy()
 
-    verify(im.convert("I;16"))
-    verify(im.convert("I;16").convert("L"))
-    verify(im.convert("I;16").convert("I"))
-
-    verify(im.convert("I;16B"))
-    verify(im.convert("I;16B").convert("L"))
-    verify(im.convert("I;16B").convert("I"))
+    for mode in ("I;16", "I;16B", "I;16N"):
+        verify(im.convert(mode))
+        verify(im.convert(mode).convert("L"))
+        verify(im.convert(mode).convert("I"))
