@@ -1,12 +1,9 @@
-import warnings
-
+from __future__ import annotations
 import pytest
 
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore", category=DeprecationWarning)
-    from PIL import ImageQt
+from PIL import ImageQt
 
-from .helper import assert_image_equal, assert_image_equal_tofile, hopper
+from .helper import assert_image_equal_tofile, assert_image_similar, hopper
 
 if ImageQt.qt_is_installed:
     from PIL.ImageQt import QPixmap
@@ -19,14 +16,6 @@ if ImageQt.qt_is_installed:
         from PySide6.QtCore import QPoint
         from PySide6.QtGui import QImage, QPainter, QRegion
         from PySide6.QtWidgets import QApplication, QHBoxLayout, QLabel, QWidget
-    elif ImageQt.qt_version == "5":
-        from PyQt5.QtCore import QPoint
-        from PyQt5.QtGui import QImage, QPainter, QRegion
-        from PyQt5.QtWidgets import QApplication, QHBoxLayout, QLabel, QWidget
-    elif ImageQt.qt_version == "side2":
-        from PySide2.QtCore import QPoint
-        from PySide2.QtGui import QImage, QPainter, QRegion
-        from PySide2.QtWidgets import QApplication, QHBoxLayout, QLabel, QWidget
 
     class Example(QWidget):
         def __init__(self):
@@ -48,7 +37,7 @@ if ImageQt.qt_is_installed:
 def roundtrip(expected):
     result = ImageQt.fromqpixmap(ImageQt.toqpixmap(expected))
     # Qt saves all pixmaps as rgb
-    assert_image_equal(result, expected.convert("RGB"))
+    assert_image_similar(result, expected.convert("RGB"), 1)
 
 
 @pytest.mark.skipif(not ImageQt.qt_is_installed, reason="Qt bindings are not installed")
