@@ -1,5 +1,5 @@
 #!/bin/sh
-# Usage: ./download-and-extract.sh something.tar.gz https://example.com/something.tar.gz
+# Usage: ./download-and-extract.sh something https://example.com/something.tar.gz
 
 archive=$1
 url=$2
@@ -8,5 +8,5 @@ if [ ! -f $archive.tar.gz ]; then
     wget -O $archive.tar.gz $url
 fi
 
-rm -r $archive
+rmdir $archive
 tar -xvzf $archive.tar.gz
