@@ -15,11 +15,11 @@
 #
 # See the README file for information on usage and redistribution.
 #
+from __future__ import annotations
 
 import array
 
 from . import GimpGradientFile, GimpPaletteFile, ImageColor, PaletteFile
-from ._deprecate import deprecate
 
 
 class ImagePalette:
@@ -34,16 +34,11 @@ class ImagePalette:
         Defaults to an empty palette.
     """
 
-    def __init__(self, mode="RGB", palette=None, size=0):
+    def __init__(self, mode="RGB", palette=None):
         self.mode = mode
         self.rawmode = None  # if set, palette contains raw data
         self.palette = palette or bytearray()
         self.dirty = None
-        if size != 0:
-            deprecate("The size parameter", 10, None)
-            if size != len(self.palette):
-                msg = "wrong palette size"
-                raise ValueError(msg)
 
     @property
     def palette(self):
@@ -108,6 +103,30 @@ class ImagePalette:
     # Declare tostring as an alias for tobytes
     tostring = tobytes
 
+    def _new_color_index(self, image=None, e=None):
+        if not isinstance(self.palette, bytearray):
+            self._palette = bytearray(self.palette)
+        index = len(self.palette) // 3
+        special_colors = ()
+        if image:
+            special_colors = (
+                image.info.get("background"),
+                image.info.get("transparency"),
+            )
+            while index in special_colors:
+                index += 1
+        if index >= 256:
+            if image:
+                # Search for an unused index
+                for i, count in reversed(list(enumerate(image.histogram()))):
+                    if count == 0 and i not in special_colors:
+                        index = i
+                        break
+            if index >= 256:
+                msg = "cannot allocate more than 256 colors"
+                raise ValueError(msg) from e
+        return index
+
     def getcolor(self, color, image=None):
         """Given an rgb tuple, allocate palette entry.
 
@@ -130,27 +149,7 @@ class ImagePalette:
                 return self.colors[color]
             except KeyError as e:
                 # allocate new color slot
-                if not isinstance(self.palette, bytearray):
-                    self._palette = bytearray(self.palette)
-                index = len(self.palette) // 3
-                special_colors = ()
-                if image:
-                    special_colors = (
-                        image.info.get("background"),
-                        image.info.get("transparency"),
-                    )
-                while index in special_colors:
-                    index += 1
-                if index >= 256:
-                    if image:
-                        # Search for an unused index
-                        for i, count in reversed(list(enumerate(image.histogram()))):
-                            if count == 0 and i not in special_colors:
-                                index = i
-                                break
-                    if index >= 256:
-                        msg = "cannot allocate more than 256 colors"
-                        raise ValueError(msg) from e
+                index = self._new_color_index(image, e)
                 self.colors[color] = index
                 if index * 3 < len(self.palette):
                     self._palette = (
@@ -206,20 +205,15 @@ def raw(rawmode, data):
 
 
 def make_linear_lut(black, white):
-    lut = []
     if black == 0:
-        for i in range(256):
-            lut.append(white * i // 255)
-    else:
-        raise NotImplementedError  # FIXME
-    return lut
+        return [white * i // 255 for i in range(256)]
+
+    msg = "unavailable when black is non-zero"
+    raise NotImplementedError(msg)  # FIXME
 
 
 def make_gamma_lut(exp):
-    lut = []
-    for i in range(256):
-        lut.append(int(((i / 255.0) ** exp) * 255.0 + 0.5))
-    return lut
+    return [int(((i / 255.0) ** exp) * 255.0 + 0.5) for i in range(256)]
 
 
 def negative(mode="RGB"):
@@ -231,9 +225,7 @@ def negative(mode="RGB"):
 def random(mode="RGB"):
     from random import randint
 
-    palette = []
-    for i in range(256 * len(mode)):
-        palette.append(randint(0, 255))
+    palette = [randint(0, 255) for _ in range(256 * len(mode))]
     return ImagePalette(mode, palette)
 
 
@@ -248,11 +240,9 @@ def wedge(mode="RGB"):
 
 
 def load(filename):
-
     # FIXME: supports GIMP gradients only
 
     with open(filename, "rb") as fp:
-
         for paletteHandler in [
             GimpPaletteFile.GimpPaletteFile,
             GimpGradientFile.GimpGradientFile,
@@ -264,8 +254,6 @@ def load(filename):
                 if lut:
                     break
             except (SyntaxError, ValueError):
-                # import traceback
-                # traceback.print_exc()
                 pass
         else:
             msg = "cannot load palette"
