@@ -13,7 +13,7 @@
 #
 # See the README file for information on usage and redistribution.
 #
-
+from __future__ import annotations
 
 import re
 
@@ -30,12 +30,10 @@ field = re.compile(rb"([a-z]*) ([^ \r\n]*)")
 
 
 class ImtImageFile(ImageFile.ImageFile):
-
     format = "IMT"
     format_description = "IM Tools"
 
     def _open(self):
-
         # Quick rejection: if there's not a LF among the first
         # 100 bytes, this is (probably) not a text header.
 
@@ -47,7 +45,6 @@ class ImtImageFile(ImageFile.ImageFile):
         xsize = ysize = 0
 
         while True:
-
             if buffer:
                 s = buffer[:1]
                 buffer = buffer[1:]
@@ -57,7 +54,6 @@ class ImtImageFile(ImageFile.ImageFile):
                 break
 
             if s == b"\x0C":
-
                 # image data begins
                 self.tile = [
                     (
@@ -71,7 +67,6 @@ class ImtImageFile(ImageFile.ImageFile):
                 break
 
             else:
-
                 # read key/value pair
                 if b"\n" not in buffer:
                     buffer += self.fp.read(100)
@@ -94,7 +89,7 @@ class ImtImageFile(ImageFile.ImageFile):
                     ysize = int(v)
                     self._size = xsize, ysize
                 elif k == b"pixel" and v == b"n8":
-                    self.mode = "L"
+                    self._mode = "L"
 
 
 #
