@@ -58,5 +58,9 @@ PyInit__imagingtk(void) {
     };
     PyObject *m;
     m = PyModule_Create(&module_def);
-    return (load_tkinter_funcs() == 0) ? m : NULL;
+    if (load_tkinter_funcs() != 0) {
+        Py_DECREF(m);
+        return NULL;
+    }
+    return m;
 }
