@@ -118,8 +118,8 @@ decode_bc3_alpha(char *dst, const UINT8 *src, int stride, int o, int sign) {
     if (sign == 1) {
         bc5s_alpha b;
         memcpy(&b, src, sizeof(bc5s_alpha));
-        a0 = (b.a0 + 255) / 2;
-        a1 = (b.a1 + 255) / 2;
+        a0 = b.a0 + 128;
+        a1 = b.a1 + 128;
         lut1 = b.lut[0] | (b.lut[1] << 8) | (b.lut[2] << 16);
         lut2 = b.lut[3] | (b.lut[4] << 8) | (b.lut[5] << 16);
     } else {
@@ -850,10 +850,12 @@ decode_bcn(
         DECODE_LOOP(3, 16, rgba);
         DECODE_LOOP(4, 8, lum);
         case 5:
+        {
+            int sign = strcmp(pixel_format, "BC5S") == 0 ? 1 : 0;
             while (bytes >= 16) {
                 rgba col[16];
-                memset(col, 0, 16 * sizeof(col[0]));
-                decode_bc5_block(col, ptr, strcmp(pixel_format, "BC5S") == 0 ? 1 : 0);
+                memset(col, sign ? 128 : 0, 16 * sizeof(col[0]));
+                decode_bc5_block(col, ptr, sign);
                 put_block(im, state, (const char *)col, sizeof(col[0]), C);
                 ptr += 16;
                 bytes -= 16;
@@ -862,10 +864,13 @@ decode_bcn(
                 }
             }
             break;
+        }
         case 6:
+        {
+            int sign = strcmp(pixel_format, "BC6HS") == 0 ? 1 : 0;
             while (bytes >= 16) {
                 rgba col[16];
-                decode_bc6_block(col, ptr, strcmp(pixel_format, "BC6HS") == 0 ? 1 : 0);
+                decode_bc6_block(col, ptr, sign);
                 put_block(im, state, (const char *)col, sizeof(col[0]), C);
                 ptr += 16;
                 bytes -= 16;
@@ -874,6 +879,7 @@ decode_bcn(
                 }
             }
             break;
+        }
         DECODE_LOOP(7, 16, rgba);
 #undef DECODE_LOOP
     }
