@@ -41,6 +41,7 @@
 #define FLOOR(v) ((v) >= 0.0 ? (int)(v) : (int)floor(v))
 
 #define INK8(ink) (*(UINT8 *)ink)
+#define INK16(ink) (*(UINT16 *)ink)
 
 /*
  * Rounds around zero (up=away from zero, down=towards zero)
@@ -68,8 +69,13 @@ static inline void
 point8(Imaging im, int x, int y, int ink) {
     if (x >= 0 && x < im->xsize && y >= 0 && y < im->ysize) {
         if (strncmp(im->mode, "I;16", 4) == 0) {
-            im->image8[y][x * 2] = (UINT8)ink;
+#ifdef WORDS_BIGENDIAN
+            im->image8[y][x * 2] = (UINT8)(ink >> 8);
             im->image8[y][x * 2 + 1] = (UINT8)ink;
+#else
+            im->image8[y][x * 2] = (UINT8)ink;
+            im->image8[y][x * 2 + 1] = (UINT8)(ink >> 8);
+#endif
         } else {
             im->image8[y][x] = (UINT8)ink;
         }
@@ -85,25 +91,22 @@ point32(Imaging im, int x, int y, int ink) {
 
 static inline void
 point32rgba(Imaging im, int x, int y, int ink) {
-    unsigned int tmp1;
+    unsigned int tmp;
 
     if (x >= 0 && x < im->xsize && y >= 0 && y < im->ysize) {
         UINT8 *out = (UINT8 *)im->image[y] + x * 4;
         UINT8 *in = (UINT8 *)&ink;
-        out[0] = BLEND(in[3], out[0], in[0], tmp1);
-        out[1] = BLEND(in[3], out[1], in[1], tmp1);
-        out[2] = BLEND(in[3], out[2], in[2], tmp1);
+        out[0] = BLEND(in[3], out[0], in[0], tmp);
+        out[1] = BLEND(in[3], out[1], in[1], tmp);
+        out[2] = BLEND(in[3], out[2], in[2], tmp);
     }
 }
 
 static inline void
 hline8(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp, pixelwidth;
+    int pixelwidth;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -126,13 +129,9 @@ hline8(Imaging im, int x0, int y0, int x1, int ink) {
 
 static inline void
 hline32(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp;
     INT32 *p;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -152,13 +151,9 @@ hline32(Imaging im, int x0, int y0, int x1, int ink) {
 
 static inline void
 hline32rgba(Imaging im, int x0, int y0, int x1, int ink) {
-    int tmp;
-    unsigned int tmp1;
+    unsigned int tmp;
 
     if (y0 >= 0 && y0 < im->ysize) {
-        if (x0 > x1) {
-            tmp = x0, x0 = x1, x1 = tmp;
-        }
         if (x0 < 0) {
             x0 = 0;
         } else if (x0 >= im->xsize) {
@@ -173,9 +168,9 @@ hline32rgba(Imaging im, int x0, int y0, int x1, int ink) {
             UINT8 *out = (UINT8 *)im->image[y0] + x0 * 4;
             UINT8 *in = (UINT8 *)&ink;
             while (x0 <= x1) {
-                out[0] = BLEND(in[3], out[0], in[0], tmp1);
-                out[1] = BLEND(in[3], out[1], in[1], tmp1);
-                out[2] = BLEND(in[3], out[2], in[2], tmp1);
+                out[0] = BLEND(in[3], out[0], in[0], tmp);
+                out[1] = BLEND(in[3], out[1], in[1], tmp);
+                out[2] = BLEND(in[3], out[2], in[2], tmp);
                 x0++;
                 out += 4;
             }
@@ -642,13 +637,17 @@ DRAW draw32rgba = {point32rgba, hline32rgba, line32rgba, polygon32rgba};
 /* Interface                                                            */
 /* -------------------------------------------------------------------- */
 
-#define DRAWINIT()                           \
-    if (im->image8) {                        \
-        draw = &draw8;                       \
-        ink = INK8(ink_);                    \
-    } else {                                 \
-        draw = (op) ? &draw32rgba : &draw32; \
-        memcpy(&ink, ink_, sizeof(ink));     \
+#define DRAWINIT()                               \
+    if (im->image8) {                            \
+        draw = &draw8;                           \
+        if (strncmp(im->mode, "I;16", 4) == 0) { \
+            ink = INK16(ink_);                   \
+        } else {                                 \
+            ink = INK8(ink_);                    \
+        }                                        \
+    } else {                                     \
+        draw = (op) ? &draw32rgba : &draw32;     \
+        memcpy(&ink, ink_, sizeof(ink));         \
     }
 
 int
