@@ -549,16 +549,16 @@ static struct {
     {"1", "1;IR", 1, pack1IR},
     {"1", "L", 8, pack1L},
 
-    /* greyscale */
+    /* grayscale */
     {"L", "L", 8, copy1},
     {"L", "L;16", 16, packL16},
     {"L", "L;16B", 16, packL16B},
 
-    /* greyscale w. alpha */
+    /* grayscale w. alpha */
     {"LA", "LA", 16, packLA},
     {"LA", "LA;L", 16, packLAL},
 
-    /* greyscale w. alpha premultiplied */
+    /* grayscale w. alpha premultiplied */
     {"La", "La", 16, packLA},
 
     /* palette */
@@ -664,6 +664,7 @@ static struct {
 #endif
     {"I;16B", "I;16B", 16, copy2},
     {"I;16L", "I;16L", 16, copy2},
+    {"I;16N", "I;16N", 16, copy2},
     {"I;16", "I;16N", 16, packI16N_I16},  // LibTiff native->image endian.
     {"I;16L", "I;16N", 16, packI16N_I16},
     {"I;16B", "I;16N", 16, packI16N_I16B},
